@@ -1,12 +1,11 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from __future__ import annotations
-from __future__ import annotations
-from __future__ import annotations
 import json
 from typing import Any
+
 import kubernetes
 from timeout_sampler import TimeoutWatch
+
 from ocp_resources.exceptions import ExecOnPodError
 from ocp_resources.node import Node
 from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
@@ -516,7 +515,7 @@ class Pod(NamespacedResource):
                 # Check remaining time, in order to throw exception
                 # if remaining time reached zero
                 if timeout_watch.remaining_time() <= 0:
-                    raise ExecOnPodError(command=command, rc=-1, out="", err=stream_closed_error)
+                    raise ExecOnPodError(command=command, rc=-1, out="", err=stream_closed_error) from None
 
         rcstring = error_channel.get("status")
         if rcstring is None:
